smartcard.wx.SimpleSCardApp

# ``smartcard`.`wx`.`SimpleSCardApp``

module documentation

Simple wxPython wxApp for smartcard.

__author__ = "gemalto http://www.gemalto.com"

Copyright 2001-2012 gemalto Author: Jean-Daniel Aussel, mailto:jean-daniel.aussel@gemalto.com

This file is part of pyscard.

pyscard is free software; you can redistribute it and/or modify it under the terms of the GNU Lesser General Public License as published by the Free Software Foundation; either version 2.1 of the License, or (at your option) any later version.

pyscard is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License along with pyscard; if not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA

Class | `SimpleSCardApp` | The SimpleSCardApp class represents the smart card application. SimpleSCardApp is a subclass of wx.App.
Constant | `PANEL_APDUTRACER` | Undocumented
Constant | `TB_READER` | Undocumented
Constant | `TB_SMARTCARD` | Undocumented
Constant | `TR_READER` | Undocumented
Constant | `TR_SMARTCARD` | Undocumented

PANEL_APDUTRACER: `int` =

Undocumented

Value
    16

TB_READER: `int` =

Undocumented

Value
    8

TB_SMARTCARD: `int` =

Undocumented

Value
    4

TR_READER: `int` =

Undocumented

Value
    2

TR_SMARTCARD: `int` =

Undocumented

Value
    1